==> testdisk_7.1.orig.tar.bz2: testdisk-7.1/README.md <==
**TestDisk** checks the partition and boot sectors of your disks.
It is very useful in recovering lost partitions.

It works with :

- DOS/Windows FAT12, FAT16 and FAT32
- NTFS ( Windows NT/2K/XP )
- Linux Ext2 and Ext3
- BeFS ( BeOS )
- BSD disklabel ( FreeBSD/OpenBSD/NetBSD )
- CramFS (Compressed File System)
- HFS and HFS+, Hierarchical File System
- JFS, IBM's Journaled File System
- Linux Raid
- Linux Swap (versions 1 and 2)
- LVM and LVM2, Linux Logical Volume Manager
- Netware NSS
- ReiserFS 3.5, 3.6 and 4
- Sun Solaris i386 disklabel
- UFS and UFS2 (Sun/BSD/...)
- XFS, SGI's Journaled File System

**PhotoRec** is file data recovery software designed to recover
lost pictures from digital camera memory or even Hard Disks.
It has been extended to search also for non audio/video headers.
It searches for

- Sun/NeXT audio data (.au)
- RIFF audio/video (.avi/.wav)
- BMP bitmap (.bmp)
- bzip2 compressed data (.bz2)
- Source code written in C (.c)
- Canon Raw picture (.crw)
- Canon catalog (.ctg)
- FAT subdirectory
- Microsoft Office Document (.doc)
- Nikon dsc (.dsc)
- HTML page (.html)
- JPEG picture (.jpg)
- MOV video (.mov)
- MP3 audio (MPEG ADTS, layer III, v1) (.mp3)
- Moving Picture Experts Group video (.mpg)
- Minolta Raw picture (.mrw)
- Olympus Raw Format picture (.orf)
- Portable Document Format (.pdf)
- Perl script (.pl)
- Portable Network Graphics (.png)
- Raw Fujifilm picture (.raf)
- Contax picture (.raw)
- Rollei picture (.rdc)
- Rich Text Format (.rtf)
- Shell script (.sh)
- Tar archive (.tar )
- Tag Image File Format (.tiff)
- Microsoft ASF (.wma)
- Sigma/Foveon X3 raw picture (.x3f)
- zip archive (.zip)

TestDisk and PhotoRec run under:

- Dos, Win9x
- Windows
- Linux
- FreeBSD, NetBSD, OpenBSD
- SunOS

Both are under GNU General Public License.

Christophe GRENIER
[grenier@cgsecurity.org](mailto:grenier@cgsecurity.org)
[https://www.cgsecurity.org/](https://www.cgsecurity.org/)

[![Build Status](https://travis-ci.org/cgsecurity/testdisk.svg?branch=master)](https://travis-ci.org/cgsecurity/testdisk)

==> testdisk_7.2.orig.tar.bz2: testdisk-7.2/README.md <==
**TestDisk** checks the partition and boot sectors of your disks.
It is very useful in recovering lost partitions.

It works with:

- DOS/Windows FAT12, FAT16 and FAT32
- NTFS (Windows NT/2K/XP)
- Linux Ext2 and Ext3
- BeFS (BeOS)
- BSD disklabel (FreeBSD/OpenBSD/NetBSD)
- CramFS (Compressed File System)
- HFS and HFS+, Hierarchical File System
- JFS, IBM's Journaled File System
- Linux Raid
- Linux Swap (versions 1 and 2)
- LVM and LVM2, Linux Logical Volume Manager
- Netware NSS
- ReiserFS 3.5, 3.6 and 4
- Sun Solaris i386 disklabel
- UFS and UFS2 (Sun/BSD/...)
- XFS, SGI's Journaled File System

**PhotoRec** is file data recovery software designed to recover
lost pictures from digital camera memory or even hard disks.
It has been extended to search also for non audio/video headers.

It searches for:

- Sun/NeXT audio data (.au)
- RIFF audio/video (.avi/.wav)
- BMP bitmap (.bmp)
- bzip2 compressed data (.bz2)
- Source code written in C (.c)
- Canon Raw picture (.crw)
- Canon catalog (.ctg)
- FAT subdirectory
- Microsoft Office Document (.doc)
- Nikon dsc (.dsc)
- HTML page (.html)
- JPEG picture (.jpg)
- MOV video (.mov)
- MP3 audio (MPEG ADTS, layer III, v1) (.mp3)
- Moving Picture Experts Group video (.mpg)
- Minolta Raw picture (.mrw)
- Olympus Raw Format picture (.orf)
- Portable Document Format (.pdf)
- Perl script (.pl)
- Portable Network Graphics (.png)
- Raw Fujifilm picture (.raf)
- Contax picture (.raw)
- Rollei picture (.rdc)
- Rich Text Format (.rtf)
- Shell script (.sh)
- Tar archive (.tar)
- Tag Image File Format (.tiff)
- Microsoft ASF (.wma)
- Sigma/Foveon X3 raw picture (.x3f)
- Zip archive (.zip)

TestDisk and PhotoRec run on:

- DOS, Win 9x
- Windows
- Linux
- FreeBSD, NetBSD, OpenBSD
- SunOS

Both are licensed under the GNU General Public License.

See the [latest documentation](https://github.com/cgsecurity/testdisk_documentation)
To build from source, read [INSTALL](INSTALL).

Christophe GRENIER
[grenier@cgsecurity.org](mailto:grenier@cgsecurity.org)
[https://www.cgsecurity.org/](https://www.cgsecurity.org/)

[![Build Status](https://travis-ci.org/cgsecurity/testdisk.svg?branch=master)](https://travis-ci.org/cgsecurity/testdisk)
